/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.asset.util;

import com.liferay.portal.kernel.util.WebKeys;

import java.util.HashSet;
import java.util.Optional;
import java.util.Set;

import javax.portlet.PortletRequest;

import javax.servlet.http.HttpServletRequest;

/**
 * @author Lourdes Fernández Besada
 */
public class LinkedAssetEntryIdsUtil {

	public static void addLinkedAssetEntryId(
		HttpServletRequest httpServletRequest, long assetEntryId) {

		Set<Long> linkedAssetEntryIds = Optional.ofNullable(
			(Set<Long>)httpServletRequest.getAttribute(
				WebKeys.LINKED_ASSET_ENTRY_IDS)
		).orElse(
			new HashSet<>()
		);

		linkedAssetEntryIds.add(assetEntryId);

		httpServletRequest.setAttribute(
			WebKeys.LINKED_ASSET_ENTRY_IDS, linkedAssetEntryIds);
	}

	public static void addLinkedAssetEntryId(
		PortletRequest portletRequest, long assetEntryId) {

		Set<Long> linkedAssetEntryIds = Optional.ofNullable(
			(Set<Long>)portletRequest.getAttribute(
				WebKeys.LINKED_ASSET_ENTRY_IDS)
		).orElse(
			new HashSet<>()
		);

		linkedAssetEntryIds.add(assetEntryId);

		portletRequest.setAttribute(
			WebKeys.LINKED_ASSET_ENTRY_IDS, linkedAssetEntryIds);
	}

	public static void replaceLinkedAssetEntryId(
		HttpServletRequest httpServletRequest, long oldAssetEntryId,
		long newAssetEntryId) {

		Set<Long> linkedAssetEntryIds = Optional.ofNullable(
			(Set<Long>)httpServletRequest.getAttribute(
				WebKeys.LINKED_ASSET_ENTRY_IDS)
		).orElse(
			new HashSet<>()
		);

		linkedAssetEntryIds.remove(oldAssetEntryId);

		linkedAssetEntryIds.add(newAssetEntryId);

		httpServletRequest.setAttribute(
			WebKeys.LINKED_ASSET_ENTRY_IDS, linkedAssetEntryIds);
	}

}